@@ -6,24 +6,24 @@
 #include <stdlib.h>
 #include <limits.h>
 
-static int min_JM (int *, int *);
-static int max_JM (int *, int *);
+static int min_JM (int, int);
+static int max_JM (int, int);
 
 static void rowcentre_JM (double *, int, int);
 static void colstandard_JM (double *, int, int);
 static void rowstd_JM (double *, int, int, int);
-static void transpose_mat_JM (double *, int *, int *, double *);
+static void transpose_mat_JM (double *, int, int, double *);
 static void mmult_JM (double *, int, int, double *, int, int, double *);
 static void orthog_mat_JM (double *, int, double *);
 static void gramsch_JM (double *, int, int, int);
-static void svd_JM (double *, int *, int *, double *, double *, double *);
+static void svd_JM (double *, int, int, double *, double *, double *);
 
 static void Symm_logcosh_JM (double *, int, double *, int, int, double, double *, double *);
 static void Symm_exp_JM (double *, int, double *, int, int, double, double *, double *);
 static void Def_logcosh_JM (double *, int, double *, int, int, double, double *);
 static void Def_exp_JM (double *, int, double *, int, int, double, double *);
-static void calc_A_JM(double*, double*, double*, int*, int*, int*, double*, double*);
-static void calc_K_JM(double*, int*, int*, double*);
+static void calc_A_JM(double*, double*, double*, int, int, int, double*, double*);
+static void calc_K_JM(double*, int, int, double*);
 
 #include <R_ext/Lapack.h>
 
@@ -73,7 +73,7 @@ colstandard_JM (double *ans, int n, int p)
 
 
 static void
-svd_JM (double *mat, int *n, int *p, double *u, double *d, double *v)
+svd_JM (double *mat, int n, int p, double *u, double *d, double *v)
 {
 
     /*  calculates svd decomposition of nxp matrix mat */
@@ -86,75 +86,79 @@ svd_JM (double *mat, int *n, int *p, double *u, double *d, double *v)
 
 
     int info, *iwork, lwork, a, b;
-    size_t iwork_size, ilwork, nn = *n, pp = *p, mm;
+    size_t iwork_size, ilwork, nn = n, pp = p, mm;
     double *work, *mat1, *u1, *v1;
     char jobz = 'A';
 
-    mm = min_JM(n,p);
+    mm = min_JM(n, p);
     iwork_size = 8 * (size_t) mm;
 
-    a = max_JM(n,p);
-    b = 4 * mm * mm + 4 * mm;
-    ilwork = 3 * mm * mm + max_JM(&a, &b);
+    a = max_JM(n, p);
+    b = (int)(4 * mm * mm + 4 * mm);
+    ilwork = 3 * mm * mm + max_JM(a, b);
+    /* FIXME: Windows objected here are nm, pp are size_t, so long long
+       But they need to be less that int since passed as int*
+       In any case, this is 32-bit rule
+    */
     if (ilwork > INT_MAX)
-	error("svd on %d x %d exceeds Fortran indexing limits");
+	Rf_error("svd on %u x %u exceeds Fortran indexing limits", n, p);
 
-    work = Calloc (ilwork, double);
-    iwork = Calloc (iwork_size, int);
-    mat1 = Calloc (nn * pp, double);
-    u1 = Calloc (nn * nn, double);
-    v1 = Calloc (pp * pp, double);
+    work = R_Calloc (ilwork, double);
+    iwork = R_Calloc (iwork_size, int);
+    mat1 = R_Calloc (nn * pp, double);
+    u1 = R_Calloc (nn * nn, double);
+    v1 = R_Calloc (pp * pp, double);
 
     transpose_mat_JM (mat, n, p, mat1);
 
-    lwork = ilwork;
-    F77_CALL (dgesdd) (&jobz, n, p, mat1, n, d, u1, n, v1, p, work,
+    lwork = (int) ilwork;
+    F77_CALL (dgesdd) (&jobz, &n, &p, mat1, &n, d, u1, &n, v1, &p, work,
 		       &lwork, iwork, &info FCONE);
 
     transpose_mat_JM (u1, n, n, u);
     transpose_mat_JM (v1, p, p, v);
 
-    Free (mat1);
-    Free (u1);
-    Free (v1);
-    Free (work);
-    Free (iwork);
+    R_Free (mat1);
+    R_Free (u1);
+    R_Free (v1);
+    R_Free (work);
+    R_Free (iwork);
 }
 
 
 static void
-transpose_mat_JM (double *mat, int *n, int *p, double *ans)
+transpose_mat_JM (double *mat, int n, int p, double *ans)
 {
 /*    transpose nxp matrix mat */
     int i, j;
 
-    for (i = 0; i < *n; i++) {
-	for (j = 0; j < *p; j++) {
-	    *(ans + j * (*n) + i) = *(mat + i * (*p) + j);
+    for (i = 0; i < n; i++) {
+	for (j = 0; j < p; j++) {
+	    *(ans + j * n + i) = *(mat + i * p + j);
 	}
     }
 }
 
 
-static int min_JM (int *a, int *b)
+static int min_JM (int a, int b)
 {
 /*  find minimum of a and b */
     int ans;
 
-    ans = *b;
-    if (*a < *b) ans = *a;
+    ans = b;
+    if (a < b) ans = a;
 
     return ans;
 }
 
-static int max_JM (int *a, int *b)
+static int max_JM (int a, int b)
 {
 /*  find maximum of a and b */
 
     int ans;
 
-    ans = *b;
-    if (*a > *b) ans = *a;
+    ans = b;
+    if (a > b) ans = a;
 
     return ans;
 }
@@ -171,7 +175,7 @@ mmult_JM (double *A, int n, int p, double *B, int q, int r, double *C)
     char transA = 'N', transB = 'N';
 
     if (p != q) {
-	error ("Error, matrices not suitable\nfor multiplication");
+	Rf_error ("Error, matrices not suitable\nfor multiplication");
     } else {
 	M = n;
 	K = p;
@@ -190,26 +194,26 @@ orthog_mat_JM (double *mat, int e, double *orthog)
 	size_t ee = e;
 
 
-	u = Calloc (ee * ee, double);
-	d = Calloc (ee, double);
-	v = Calloc (ee * ee, double);
-	temp = Calloc (ee * ee, double);
+	u = R_Calloc (ee * ee, double);
+	d = R_Calloc (ee, double);
+	v = R_Calloc (ee * ee, double);
+	temp = R_Calloc (ee * ee, double);
 
-	svd_JM (mat, &e, &e, u, d, v);
+	svd_JM (mat, e, e, u, d, v);
 	for (i = 0; i < e; i++) {
 		temp[i * e + i] = 1 / (d[i]);
 	}
 
 	mmult_JM (u, e, e, temp, e, e, v);
-	transpose_mat_JM (u, &e, &e, temp);
+	transpose_mat_JM (u, e, e, temp);
 	mmult_JM (v, e, e, temp, e, e, u);
 	mmult_JM (u, e, e, mat, e, e, orthog);
 
 
-	Free (u);
-	Free (v);
-	Free (d);
-	Free (temp);
+	R_Free (u);
+	R_Free (v);
+	R_Free (d);
+	R_Free (temp);
 
 }
 
@@ -224,17 +228,17 @@ Symm_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha
 	double mean;
 
 	if (e != f) {
-		error ("error in Symm_logcosh_JM, dims dont match");
+		Rf_error ("error in Symm_logcosh_JM, dims dont match");
 	}
 	else {
 		size_t es = (size_t)e * (size_t)e;
 		size_t ep = (size_t)e * (size_t)p;
-		mat1 = Calloc (ep, double);
-		mat2 = Calloc (ep, double);
-		mat3 = Calloc (es, double);
-		mat4 = Calloc (es, double);
-		mat5 = Calloc (es, double);
-		mat6 = Calloc (es, double);
+		mat1 = R_Calloc (ep, double);
+		mat2 = R_Calloc (ep, double);
+		mat3 = R_Calloc (es, double);
+		mat4 = R_Calloc (es, double);
+		mat5 = R_Calloc (es, double);
+		mat6 = R_Calloc (es, double);
 
 		mmult_JM (w_init, e, e, data, e, p, mat1);
 
@@ -244,7 +248,7 @@ Symm_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha
 				mat1[i * p + j] = tanh (alpha * mat1[i * p + j]);
 			}
 		}
-		transpose_mat_JM (data, &e, &p, mat2);
+		transpose_mat_JM (data, e, p, mat2);
 		for (i = 0; i < e; i++) {
 			for (j = 0; j < p; j++) {
 				mat2[i * p + j] = (mat2[i * p + j]) / p;
@@ -272,7 +276,7 @@ Symm_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha
 			}
 		}
 
-		transpose_mat_JM (w_init, &e, &e, mat6);
+		transpose_mat_JM (w_init, e, e, mat6);
 		orthog_mat_JM (mat4, e, w_final);
 
 
@@ -284,12 +288,12 @@ Symm_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha
 			}
 		}
 		*Tol = mean;
-		Free (mat1);
-		Free (mat2);
-		Free (mat3);
-		Free (mat4);
-		Free (mat5);
-		Free (mat6);
+		R_Free (mat1);
+		R_Free (mat2);
+		R_Free (mat3);
+		R_Free (mat4);
+		R_Free (mat5);
+		R_Free (mat6);
 	}
 }
 
@@ -303,13 +307,13 @@ Def_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha,
 	double mean;
 
 	if (e != f) {
-		error ("error in Def_logcosh_JM, dims dont match");
+		Rf_error ("error in Def_logcosh_JM, dims dont match");
 	}
 	else {
-		mat1 = Calloc (p, double);
-		mat2 = Calloc ((size_t)e * (size_t)p, double);
-		mat3 = Calloc (e, double);
-		mat4 = Calloc (e, double);
+		mat1 = R_Calloc (p, double);
+		mat2 = R_Calloc ((size_t)e * (size_t)p, double);
+		mat3 = R_Calloc (e, double);
+		mat4 = R_Calloc (e, double);
 
 		mmult_JM (w_init, 1, e, data, e, p, mat1);
 
@@ -317,7 +321,7 @@ Def_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha,
 		for (i = 0; i < p; i++) {
 			mat1[i] = tanh (alpha * mat1[i]);
 		}
-		transpose_mat_JM (data, &e, &p, mat2);
+		transpose_mat_JM (data, e, p, mat2);
 		for (i = 0; i < e; i++) {
 			for (j = 0; j < p; j++) {
 				mat2[i * p + j] = (mat2[i * p + j]) / p;
@@ -340,10 +344,10 @@ Def_logcosh_JM (double *w_init, int e, double *data, int f, int p, double alpha,
 			w_final[i] = (mat3[i] - mat4[i]);
 		}
 
-		Free (mat1);
-		Free (mat2);
-		Free (mat3);
-		Free (mat4);
+		R_Free (mat1);
+		R_Free (mat2);
+		R_Free (mat3);
+		R_Free (mat4);
 
 	}
 }
@@ -358,18 +362,18 @@ int i, j;
 double mean;
 
 if (e != f) {
-    error ("error in Symm_exp_JM, dims dont match");
+    Rf_error ("error in Symm_exp_JM, dims dont match");
 }
 else {
     size_t ep = (size_t)e * (size_t)p;
     size_t ee = (size_t)e * (size_t)e;
-    mat0 = Calloc (ep, double);
-    mat1 = Calloc (ep, double);
-    mat2 = Calloc (ep, double);
-    mat3 = Calloc (ee, double);
-    mat4 = Calloc (ee, double);
-    mat5 = Calloc (ee, double);
-    mat6 = Calloc (ee, double);
+    mat0 = R_Calloc (ep, double);
+    mat1 = R_Calloc (ep, double);
+    mat2 = R_Calloc (ep, double);
+    mat3 = R_Calloc (ee, double);
+    mat4 = R_Calloc (ee, double);
+    mat5 = R_Calloc (ee, double);
+    mat6 = R_Calloc (ee, double);
     mmult_JM (w_init, e, e, data, e, p, mat1);
     for (i = 0; i < e; i++) {
 	for (j = 0; j < p; j++) {
@@ -378,7 +382,7 @@ else {
 					 (mat1[i * p + j]));
 	}
     }
-    transpose_mat_JM (data, &e, &p, mat2);
+    transpose_mat_JM (data, e, p, mat2);
     for (i = 0; i < e; i++) {
 	for (j = 0; j < p; j++) {
 	    mat2[i * p + j] = (mat2[i * p + j]) / p;
@@ -407,7 +411,7 @@ else {
 	}
     }
 
-    transpose_mat_JM (w_init, &e, &e, mat6);
+    transpose_mat_JM (w_init, e, e, mat6);
     orthog_mat_JM (mat4, e, w_final);
 
     mmult_JM (w_final, e, e, mat6, e, e, mat5);
@@ -418,13 +422,13 @@ else {
 	}
     }
     *Tol = mean;
-    Free (mat1);
-    Free (mat2);
-    Free (mat3);
-    Free (mat4);
-    Free (mat5);
-    Free (mat0);
-    Free (mat6);
+    R_Free (mat1);
+    R_Free (mat2);
+    R_Free (mat3);
+    R_Free (mat4);
+    R_Free (mat5);
+    R_Free (mat0);
+    R_Free (mat6);
 }
 }
 
@@ -438,13 +442,13 @@ int i, j;
 double mean;
 
 if (e != f) {
-    error ("error in Def_exp_JM, dims dont match");
+    Rf_error ("error in Def_exp_JM, dims dont match");
 }
 else {
-    mat1 = Calloc (p, double);
-    mat2 = Calloc ((size_t)e * (size_t)p, double);
-    mat3 = Calloc (e, double);
-    mat4 = Calloc (e, double);
+    mat1 = R_Calloc (p, double);
+    mat2 = R_Calloc ((size_t)e * (size_t)p, double);
+    mat3 = R_Calloc (e, double);
+    mat4 = R_Calloc (e, double);
 
     mmult_JM (w_init, 1, e, data, e, p, mat1);
 
@@ -452,7 +456,7 @@ else {
 	mat1[i] = ((mat1[i]) * exp (-0.5 * (mat1[i]) * (mat1[i])));
     }
 
-    transpose_mat_JM (data, &e, &p, mat2);
+    transpose_mat_JM (data, e, p, mat2);
     for (i = 0; i < e; i++) {
 	for (j = 0; j < p; j++) {
 	    mat2[i * p + j] = (mat2[i * p + j]) / p;
@@ -479,10 +483,10 @@ else {
     }
 
 
-    Free (mat1);
-    Free (mat2);
-    Free (mat3);
-    Free (mat4);
+    R_Free (mat1);
+    R_Free (mat2);
+    R_Free (mat3);
+    R_Free (mat4);
 
 }
 }
@@ -495,7 +499,7 @@ double tmp;
 /* do Gram-Schmidt on row k of (n*m) matrix ww */
 k -= 1;
 if (k > n) {
-    error ("Error in gramsch");
+    Rf_error ("Error in gramsch");
 }
 else {
     for (ip = 0; ip < k; ip++) {
@@ -518,7 +522,7 @@ double tmp = 0;
 int i;
 k -= 1;
 if (k > n) {
-    error ("Error in rowstd");
+    Rf_error ("Error in rowstd");
 }
 else {
     for (i = 0; i < m; i++) {
@@ -533,103 +537,104 @@ else {
 
 
 static void
-calc_K_JM(double *x, int *n, int *p, double *K)
+calc_K_JM(double *x, int n, int p, double *K)
 {
     int i, j;
     double *xxt, *xt, *u, *d, *v, *temp1, *temp2;
-    size_t nn = *n, pp = *p;
+    size_t nn = n, pp = p;
 
-    xxt = Calloc (nn * nn, double);
-    xt = Calloc (nn * pp, double);
+    xxt = R_Calloc (nn * nn, double);
+    xt = R_Calloc (nn * pp, double);
 
     /* transpose x matrix */
     transpose_mat_JM (x, n, p, xt);
 
     /* calculate sample covariance matrix xxt */
-    mmult_JM (x, *n, *p, xt, *p, *n, xxt);
-    for (i = 0; i < *n; i++) {
-	for (j = 0; j < *n; j++) {
-	    xxt[*n * i + j] = xxt[*n * i + j] / *p;
+    mmult_JM (x, n, p, xt, p, n, xxt);
+    for (i = 0; i < n; i++) {
+	for (j = 0; j < n; j++) {
+	    xxt[n * i + j] = xxt[n * i + j] / p;
 	}
     }
-    Free (xt);
+    R_Free (xt);
 
     /* calculate svd decomposition of xxt */
-    u = Calloc (nn * nn, double);
-    d = Calloc (nn, double);
-    v = Calloc (nn * nn, double);
+    u = R_Calloc (nn * nn, double);
+    d = R_Calloc (nn, double);
+    v = R_Calloc (nn * nn, double);
 
     svd_JM (xxt, n, n, u, d, v);
 
     /* calculate K matrix*/
-    temp1 = Calloc (nn * nn, double);
-    temp2 = Calloc (nn * nn, double);
+    temp1 = R_Calloc (nn * nn, double);
+    temp2 = R_Calloc (nn * nn, double);
 
-    for (i = 0; i < *n; i++) {
-	temp1[*n * i + i] = 1 / sqrt (d[i]);
+    for (i = 0; i < n; i++) {
+	temp1[n * i + i] = 1 / sqrt (d[i]);
     }
 
     transpose_mat_JM (u, n, n, temp2);
-    mmult_JM (temp1, *n, *n, temp2, *n, *n, K);
+    mmult_JM (temp1, n, n, temp2, n, n, K);
 
-    Free (temp1);
-    Free (temp2);
-    Free(xxt);
-    Free(u);
-    Free(d);
-    Free(v);
+    R_Free (temp1);
+    R_Free (temp2);
+    R_Free(xxt);
+    R_Free(u);
+    R_Free(d);
+    R_Free(v);
 }
 
 static void
 calc_A_JM(double *w, double *k, double *data,
-	  int *e, int *n, int *p, double *A, double *unmixed_data)
+	  int e, int n, int p, double *A, double *unmixed_data)
 {
     /* calculate un-mixing matrix A */
     int i;
     double *um, *umt, *umumt, *uu, *dd, *vv, *temp1, *temp2, *temp3;
-    size_t nn = *n, ee = *e;
+    size_t nn = n, ee = e;
 
-    um = Calloc (ee * nn, double);
-    umt = Calloc (nn * ee, double);
+    um = R_Calloc (ee * nn, double);
+    umt = R_Calloc (nn * ee, double);
 
-    mmult_JM (w, *e, *e, k, *e, *n, um);
-    mmult_JM (um, *e, *n, data, *n, *p, unmixed_data);
+    mmult_JM (w, e, e, k, e, n, um);
+    mmult_JM (um, e, n, data, n, p, unmixed_data);
     transpose_mat_JM (um, e, n, umt);
 
-    umumt = Calloc (ee * ee, double);
-    mmult_JM (um, *e, *n, umt, *n, *e, umumt);
+    umumt = R_Calloc (ee * ee, double);
+    mmult_JM (um, e, n, umt, n, e, umumt);
 
-    uu = Calloc (ee * ee, double);
-    dd = Calloc (ee, double);
-    vv = Calloc (ee * ee, double);
+    uu = R_Calloc (ee * ee, double);
+    dd = R_Calloc (ee, double);
+    vv = R_Calloc (ee * ee, double);
     svd_JM (umumt, e, e, uu, dd, vv);
 
-    temp1 = Calloc (ee * ee, double);
-    for (i = 0; i < *e; i++) {
-	temp1[*e * i + i] = 1 / (dd[i]);
+    temp1 = R_Calloc (ee * ee, double);
+    for (i = 0; i < e; i++) {
+	temp1[e * i + i] = 1 / (dd[i]);
     }
 
-    temp2 = Calloc (ee * ee, double);
-    temp3 = Calloc (ee * ee, double);
+    temp2 = R_Calloc (ee * ee, double);
+    temp3 = R_Calloc (ee * ee, double);
     transpose_mat_JM (vv, e, e, temp3);
-    mmult_JM (temp3, *e, *e, temp1, *e, *e, temp2);
+    mmult_JM (temp3, e, e, temp1, e, e, temp2);
     transpose_mat_JM (uu, e, e, vv);
-    mmult_JM (temp2, *e, *e, vv, *e, *e, uu);
+    mmult_JM (temp2, e, e, vv, e, e, uu);
 
-    mmult_JM (umt, *n, *e, uu, *e, *e, A);
+    mmult_JM (umt, n, e, uu, e, e, A);
 
-    Free(um);
-    Free(umt);
-    Free(umumt);
-    Free(uu);
-    Free(dd);
-    Free(vv);
-    Free(temp1);
-    Free(temp2);
-    Free(temp3);
+    R_Free(um);
+    R_Free(umt);
+    R_Free(umumt);
+    R_Free(uu);
+    R_Free(dd);
+    R_Free(vv);
+    R_Free(temp1);
+    R_Free(temp2);
+    R_Free(temp3);
 
 }
 
+// This is the sole function called from R.
 static void
 icainc_JM (double *data_matrix, double *w_matrix, int *nn, int *pp, int *ee,
 	double *alpha, int *rowflag, int *colflag, int *funflag, int *maxit,
@@ -640,20 +645,20 @@ icainc_JM (double *data_matrix, double *w_matrix, int *nn, int *pp, int *ee,
     /* main ICA function */
 
     int i, j, k;
-    size_t n = *nn, p = *pp, e = *ee;
+    int n = *nn, p = *pp, e = *ee;
     double tol;
     double *temp_w1, *temp_w2;
     double *data1, *Kmat, *temp1, *w_init;
 
-    /* make a copy of the data matrix*/
-    data1 = Calloc (n * p, double);
+    /* make a copy of the data matrix */
+    data1 = R_Calloc (n * p, double);
     for (i = 0; i < n; i++) {
 	for (j = 0; j < p; j++) {
 	    data_pre[i * p + j] = data_matrix[i * p + j];
 	}
     }
 
-    /* row center data matrix if required*/
+    /* row center data matrix if required */
     if (*rowflag == 1) {
 	rowcentre_JM (data_pre, n, p);
 	if (*verbose == 1)
@@ -668,8 +673,8 @@ icainc_JM (double *data_matrix, double *w_matrix, int *nn, int *pp, int *ee,
 
     /* calculate pre-whitening matrix Kmat */
     if (*verbose == 1)	Rprintf ("Whitening\n");
-    Kmat = Calloc (n * n, double);
-    calc_K_JM(data_pre, nn, pp, Kmat);
+    Kmat = R_Calloc (n * n, double);
+    calc_K_JM(data_pre, n, p, Kmat);
 
     /* pre-whiten data and reduce dimension from size n to size e */
 
@@ -681,8 +686,8 @@ icainc_JM (double *data_matrix, double *w_matrix, int *nn, int *pp, int *ee,
     mmult_JM (Kmat1, e, n, data_pre, n, p, data1);
 
     /* calculate initial (orthogonal) unmixing matrix w */
-    temp1 = Calloc (e * e, double);
-    w_init = Calloc (e * e, double);
+    temp1 = R_Calloc (e * e, double);
+    w_init = R_Calloc (e * e, double);
     for (i = 0; i < e; i++) {
 	for (j = 0; j < e; j++) {
 	    temp1[i * e + j] = w_matrix[i * e + j];
@@ -728,8 +733,8 @@ icainc_JM (double *data_matrix, double *w_matrix, int *nn, int *pp, int *ee,
     }
 
     if (*defflag == 1) {
-	temp_w1 = Calloc (e, double);
-	temp_w2 = Calloc (e, double);
+	temp_w1 = R_Calloc (e, double);
+	temp_w2 = R_Calloc (e, double);
 
 	if (*funflag == 1) {
 	    if (*verbose == 1)
@@ -805,17 +810,17 @@ icainc_JM (double *data_matrix, double *w_matrix, int *nn, int *pp, int *ee,
 		w_final[i * e + j] = w_init[i * e + j];
 	    }
 	}
-	Free (temp_w1);
-	Free (temp_w2);
+	R_Free (temp_w1);
+	R_Free (temp_w2);
     }
 
     /* calculate mixing matrix ansa */
-    calc_A_JM(w_final, Kmat1, data_pre, ee, nn, pp, ansa, ansx2);
+    calc_A_JM(w_final, Kmat1, data_pre, e, n, p, ansa, ansx2);
 
-    Free (data1);
-    Free (Kmat);
-    Free (temp1);
-    Free (w_init);
+    R_Free (data1);
+    R_Free (Kmat);
+    R_Free (temp1);
+    R_Free (w_init);
 }
 
 #include <R_ext/Rdynload.h>
